//$Id: widget.cc,v 1.11 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "widget.h"

#include "resource-manager.h"

using namespace Guikachu;

Widgets::Widget::Widget (Resources::Form *owner_,
			 const string&    id_):
    owner (owner_),
    id (changed, id_),
    x (changed, 0),
    y (changed, 0)
{
}   

ostream& Widgets::operator<< (ostream &ostr, const Widget* res)
{
    res->save_rcp (ostr);
    return ostr;
}
